LIBRARY ieee;
USE ieee.STD_LOGIC_1164.ALL;
USE ieee.numeric_std.ALL;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;

--##############################################################################
--ENTITY NAME : huffman
--GENERICS    :
--Description :
--##############################################################################

ENTITY huffman IS

GENERIC(len_enc_value     : integer := 3; --
        table_index_len  : integer := 4; --which huffman table
        n            : integer := 9  --not being used 5Feb08:19
);

PORT(
     clr_n         : IN  std_logic;
     
     --the input start goes '1', as soon as the mp3bit_stream is carring
     --hcods. It is thought that soon after scalfactors, hcods will begin
     --So after part2_len no of clocks after side info, mp3bit_stream
     --is expected to carry huffman codes.
     start         : IN  std_logic;
     mp3bit_stream : IN  std_logic;
--
     xx_0_value : OUT std_logic_vector(len_enc_value downto 0);
     xx_1_value : OUT std_logic_vector(len_enc_value downto 0);
--#b#
     --It selects which huffman table to be selected.
     table_sel     : IN  std_logic_vector(table_index_len downto 0);
     h_len         : OUT std_logic_vector(2 downto 0);--may  not be of use;
     --h_len will be deleted, just kept in dev phase, as an o/p so that it
     --might be monitored.
    
     ps_vec        : OUT std_logic_vector(9 downto 0);     

     found         : OUT std_logic;     
     
     clk_in        : IN  std_logic
     );

END huffman;



--##############################################################################
--Architecture starts here
--##############################################################################

ARCHITECTURE rtl OF huffman IS
--##############################################################################
--Description
--##############################################################################



--##############################################################################
--SIGNAL Declaration Section Begins
--##############################################################################


SIGNAL ps : integer range 0 to 511;
SIGNAL ns : integer range 0 to 511;

SIGNAL inp : std_logic;

SIGNAL ps_vec_sig : std_logic_vector(9 downto 0);
SIGNAL table_sel_sig : std_logic_vector(table_index_len downto 0);

SIGNAL found_sync : std_logic;
SIGNAL found_sig : std_logic;
--
SIGNAL xx_0_val : std_logic_vector(len_enc_value downto 0);
SIGNAL xx_1_val : std_logic_vector(len_enc_value downto 0);
SIGNAL xx_0_val_sync : std_logic_vector(len_enc_value downto 0);
SIGNAL xx_1_val_sync : std_logic_vector(len_enc_value downto 0);
--#b#


--##############################################################################
--FUNCTION Declaration Section Begins
--##############################################################################
BEGIN

inp <= mp3bit_stream;
found <= found_sync;
table_sel_sig <= table_sel;

ps_vec_sig <= STD_LOGIC_VECTOR(to_unsigned(ps,ps_vec_sig'length));
ps_vec <= ps_vec_sig;

st_mac: PROCESS(ps,inp,table_sel_sig)
VARIABLE table_sel_var : std_logic_vector(4 downto 0);
BEGIN
table_sel_var := table_sel_sig;

  CASE ps IS
    WHEN 0   =>
      IF(inp = '1') THEN
        ns <= 1 ;--A -- 1
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 2 ;--B -- 2
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 1  =>
      IF(inp = '1') THEN
        ns <= 3 ;--AA -- 3
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 4 ;--AB -- 4
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 2  =>
      IF(inp = '1') THEN
        ns <= 5 ;--BA -- 5
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 6 ;--BB -- 6
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 3  =>
      IF(inp = '1') THEN
        ns <= 7 ;--AAA -- 7
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 8 ;--AAB -- 8
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 4  =>
      IF(inp = '1') THEN
        ns <= 9 ;--ABA -- 9
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 10 ;--ABB -- 10
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 5  =>
      IF(inp = '1') THEN
        ns <= 11 ;--BAA -- 11
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 12 ;--BAB -- 12
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 6  =>
      IF(inp = '1') THEN
        ns <= 13 ;--BBA -- 13
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 14 ;--BBB -- 14
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 7  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 15 
        xx_0_val <= "0000";
        xx_1_val <= "0000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 16 
        xx_0_val <= "0001";
        xx_1_val <= "0000";
      END IF;
    WHEN 8  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 17 
        xx_0_val <= "0000";
        xx_1_val <= "0001";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 18 
        xx_0_val <= "0001";
        xx_1_val <= "0001";
      END IF;
    WHEN 9  =>
      IF(inp = '1') THEN
        ns <= 19 ;--ABAA -- 19
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 20 ;--ABAB -- 20
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 10  =>
      IF(inp = '1') THEN
        ns <= 21 ;--ABBA -- 21
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 22 ;--ABBB -- 22
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 11  =>
      IF(inp = '1') THEN
        ns <= 23 ;--BAAA -- 23
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 24 ;--BAAB -- 24
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 12  =>
      IF(inp = '1') THEN
        ns <= 25 ;--BABA -- 25
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 26 ;--BABB -- 26
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 13  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 27 
        xx_0_val <= "1111";
        xx_1_val <= "1111";
      ELSE
        ns <= 28 ;--BBAB -- 28
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 14  =>
      IF(inp = '1') THEN
        ns <= 29 ;--BBBA -- 29
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 30 ;--BBBB -- 30
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 19  =>
      IF(inp = '1') THEN
        ns <= 31 ;--ABAAA -- 31
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 32 
        xx_0_val <= "0010";
        xx_1_val <= "0001";
      END IF;
    WHEN 20  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 33 
        xx_0_val <= "0001";
        xx_1_val <= "0010";
      ELSE
        ns <= 34 ;--ABABB -- 34
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 21  =>
      IF(inp = '1') THEN
        ns <= 35 ;--ABBAA -- 35
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 36 ;--ABBAB -- 36
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 22  =>
      IF(inp = '1') THEN
        ns <= 37 ;--ABBBA -- 37
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 38 ;--ABBBB -- 38
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 23  =>
      IF(inp = '1') THEN
        ns <= 39 ;--BAAAA -- 39
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 40 ;--BAAAB -- 40
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 24  =>
      IF(inp = '1') THEN
        ns <= 41 ;--BAABA -- 41
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 42 ;--BAABB -- 42
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 25  =>
      IF(inp = '1') THEN
        ns <= 43 ;--BABAA -- 43
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 44 ;--BABAB -- 44
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 26  =>
      IF(inp = '1') THEN
        ns <= 45 ;--BABBA -- 45
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 46 ;--BABBB -- 46
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 28  =>
      IF(inp = '1') THEN
        ns <= 47 ;--BBABA -- 47
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 48 ;--BBABB -- 48
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 29  =>
      IF(inp = '1') THEN
        ns <= 49 ;--BBBAA -- 49
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 50 ;--BBBAB -- 50
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 30  =>
      IF(inp = '1') THEN
        ns <= 51 ;--BBBBA -- 51
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 52 ;--BBBBB -- 52
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 31  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 53 
        xx_0_val <= "0010";
        xx_1_val <= "0000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 54 
        xx_0_val <= "0000";
        xx_1_val <= "0010";
      END IF;
    WHEN 34  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 55 
        xx_0_val <= "0010";
        xx_1_val <= "0010";
      ELSE
        ns <= 56 ;--ABABBB -- 56
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 35  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 57 
        xx_0_val <= "0011";
        xx_1_val <= "0001";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 58 
        xx_0_val <= "0001";
        xx_1_val <= "0011";
      END IF;
    WHEN 36  =>
      IF(inp = '1') THEN
        ns <= 59 ;--ABBABA -- 59
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 60 ;--ABBABB -- 60
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 37  =>
      IF(inp = '1') THEN
        ns <= 61 ;--ABBBAA -- 61
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 62 ;--ABBBAB -- 62
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 38  =>
      IF(inp = '1') THEN
        ns <= 63 ;--ABBBBA -- 63
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 64 ;--ABBBBB -- 64
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 39  =>
      IF(inp = '1') THEN
        ns <= 65 ;--BAAAAA -- 65
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 66 ;--BAAAAB -- 66
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 40  =>
      IF(inp = '1') THEN
        ns <= 67 ;--BAAABA -- 67
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 68 ;--BAAABB -- 68
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 41  =>
      IF(inp = '1') THEN
        ns <= 69 ;--BAABAA -- 69
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 70 ;--BAABAB -- 70
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 42  =>
      IF(inp = '1') THEN
        ns <= 71 ;--BAABBA -- 71
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 72 ;--BAABBB -- 72
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 43  =>
      IF(inp = '1') THEN
        ns <= 73 ;--BABAAA -- 73
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 74 ;--BABAAB -- 74
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 44  =>
      IF(inp = '1') THEN
        ns <= 75 ;--BABABA -- 75
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 76 ;--BABABB -- 76
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 45  =>
      IF(inp = '1') THEN
        ns <= 77 ;--BABBAA -- 77
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 78 ;--BABBAB -- 78
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 46  =>
      IF(inp = '1') THEN
        ns <= 79 ;--BABBBA -- 79
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 80 ;--BABBBB -- 80
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 47  =>
      IF(inp = '1') THEN
        ns <= 81 ;--BBABAA -- 81
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 82 ;--BBABAB -- 82
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 48  =>
      IF(inp = '1') THEN
        ns <= 83 ;--BBABBA -- 83
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 84 ;--BBABBB -- 84
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 49  =>
      IF(inp = '1') THEN
        ns <= 85 ;--BBBAAA -- 85
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 86 ;--BBBAAB -- 86
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 50  =>
      IF(inp = '1') THEN
        ns <= 87 ;--BBBABA -- 87
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 88 ;--BBBABB -- 88
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 51  =>
      IF(inp = '1') THEN
        ns <= 89 ;--BBBBAA -- 89
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 90 ;--BBBBAB -- 90
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 52  =>
      IF(inp = '1') THEN
        ns <= 91 ;--BBBBBA -- 91
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 92 ;--BBBBBB -- 92
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 56  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 93 
        xx_0_val <= "0011";
        xx_1_val <= "0000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 94 
        xx_0_val <= "0000";
        xx_1_val <= "0011";
      END IF;
    WHEN 59  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 95 
        xx_0_val <= "0011";
        xx_1_val <= "0010";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 96 
        xx_0_val <= "0010";
        xx_1_val <= "0011";
      END IF;
    WHEN 60  =>
      IF(inp = '1') THEN
        ns <= 97 ;--ABBABBA -- 97
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 98 
        xx_0_val <= "0100";
        xx_1_val <= "0001";
      END IF;
    WHEN 61  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 99 
        xx_0_val <= "0001";
        xx_1_val <= "0100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 100 
        xx_0_val <= "0011";
        xx_1_val <= "0011";
      END IF;
    WHEN 62  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 101 
        xx_0_val <= "0100";
        xx_1_val <= "0010";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 102 
        xx_0_val <= "0010";
        xx_1_val <= "0100";
      END IF;
    WHEN 63  =>
      IF(inp = '1') THEN
        ns <= 103 ;--ABBBBAA -- 103
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 104 
        xx_0_val <= "0101";
        xx_1_val <= "0001";
      END IF;
    WHEN 64  =>
      IF(inp = '1') THEN
        ns <= 105 ;--ABBBBBA -- 105
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 106 ;--ABBBBBB -- 106
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 65  =>
      IF(inp = '1') THEN
        ns <= 107 ;--BAAAAAA -- 107
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 108 ;--BAAAAAB -- 108
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 66  =>
      IF(inp = '1') THEN
        ns <= 109 ;--BAAAABA -- 109
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 110 ;--BAAAABB -- 110
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 67  =>
      IF(inp = '1') THEN
        ns <= 111 ;--BAAABAA -- 111
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 112 ;--BAAABAB -- 112
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 68  =>
      IF(inp = '1') THEN
        ns <= 113 ;--BAAABBA -- 113
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 114 ;--BAAABBB -- 114
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 69  =>
      IF(inp = '1') THEN
        ns <= 115 ;--BAABAAA -- 115
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 116 ;--BAABAAB -- 116
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 70  =>
      IF(inp = '1') THEN
        ns <= 117 ;--BAABABA -- 117
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 118 ;--BAABABB -- 118
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 71  =>
      IF(inp = '1') THEN
        ns <= 119 ;--BAABBAA -- 119
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 120 ;--BAABBAB -- 120
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 72  =>
      IF(inp = '1') THEN
        ns <= 121 ;--BAABBBA -- 121
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 122 ;--BAABBBB -- 122
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 73  =>
      IF(inp = '1') THEN
        ns <= 123 ;--BABAAAA -- 123
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 124 ;--BABAAAB -- 124
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 74  =>
      IF(inp = '1') THEN
        ns <= 125 ;--BABAABA -- 125
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 126 ;--BABAABB -- 126
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 75  =>
      IF(inp = '1') THEN
        ns <= 127 ;--BABABAA -- 127
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 128 ;--BABABAB -- 128
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 76  =>
      IF(inp = '1') THEN
        ns <= 129 ;--BABABBA -- 129
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 130 ;--BABABBB -- 130
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 77  =>
      IF(inp = '1') THEN
        ns <= 131 ;--BABBAAA -- 131
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 132 ;--BABBAAB -- 132
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 78  =>
      IF(inp = '1') THEN
        ns <= 133 ;--BABBABA -- 133
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 134 ;--BABBABB -- 134
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 79  =>
      IF(inp = '1') THEN
        ns <= 135 ;--BABBBAA -- 135
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 136 ;--BABBBAB -- 136
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 80  =>
      IF(inp = '1') THEN
        ns <= 137 ;--BABBBBA -- 137
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 138 ;--BABBBBB -- 138
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 81  =>
      IF(inp = '1') THEN
        ns <= 139 ;--BBABAAA -- 139
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 140 ;--BBABAAB -- 140
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 82  =>
      IF(inp = '1') THEN
        ns <= 141 ;--BBABABA -- 141
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 142 
        xx_0_val <= "1111";
        xx_1_val <= "0001";
      END IF;
    WHEN 83  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 143 
        xx_0_val <= "1111";
        xx_1_val <= "0010";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 144 
        xx_0_val <= "0010";
        xx_1_val <= "1111";
      END IF;
    WHEN 84  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 145 
        xx_0_val <= "1111";
        xx_1_val <= "0011";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 146 
        xx_0_val <= "0011";
        xx_1_val <= "1111";
      END IF;
    WHEN 85  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 147 
        xx_0_val <= "1111";
        xx_1_val <= "0100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 148 
        xx_0_val <= "0100";
        xx_1_val <= "1111";
      END IF;
    WHEN 86  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 149 
        xx_0_val <= "1111";
        xx_1_val <= "0101";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 150 
        xx_0_val <= "0101";
        xx_1_val <= "1111";
      END IF;
    WHEN 87  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 151 
        xx_0_val <= "1111";
        xx_1_val <= "0110";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 152 
        xx_0_val <= "0110";
        xx_1_val <= "1111";
      END IF;
    WHEN 88  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 153 
        xx_0_val <= "1111";
        xx_1_val <= "0111";
      ELSE
        ns <= 154 ;--BBBABBB -- 154
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 89  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 155 
        xx_0_val <= "1111";
        xx_1_val <= "1000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 156 
        xx_0_val <= "1111";
        xx_1_val <= "1001";
      END IF;
    WHEN 90  =>
      IF(inp = '1') THEN
        ns <= 157 ;--BBBBABA -- 157
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 158 
        xx_0_val <= "1111";
        xx_1_val <= "1010";
      END IF;
    WHEN 91  =>
      IF(inp = '1') THEN
        ns <= 159 ;--BBBBBAA -- 159
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 160 ;--BBBBBAB -- 160
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 92  =>
      IF(inp = '1') THEN
        ns <= 161 ;--BBBBBBA -- 161
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 162 ;--BBBBBBB -- 162
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 97  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 163 
        xx_0_val <= "0100";
        xx_1_val <= "0000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 164 
        xx_0_val <= "0000";
        xx_1_val <= "0100";
      END IF;
    WHEN 103  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 165 
        xx_0_val <= "0100";
        xx_1_val <= "0011";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 166 
        xx_0_val <= "0011";
        xx_1_val <= "0100";
      END IF;
    WHEN 105  =>
      IF(inp = '1') THEN
        ns <= 167 ;--ABBBBBAA -- 167
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 168 
        xx_0_val <= "0001";
        xx_1_val <= "0101";
      END IF;
    WHEN 106  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 169 
        xx_0_val <= "0101";
        xx_1_val <= "0010";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 170 
        xx_0_val <= "0010";
        xx_1_val <= "0101";
      END IF;
    WHEN 107  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 171 
        xx_0_val <= "0100";
        xx_1_val <= "0100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 172 
        xx_0_val <= "0101";
        xx_1_val <= "0011";
      END IF;
    WHEN 108  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 173 
        xx_0_val <= "0011";
        xx_1_val <= "0101";
      ELSE
        ns <= 174 ;--BAAAAABB -- 174
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 109  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 175 
        xx_0_val <= "0110";
        xx_1_val <= "0001";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 176 
        xx_0_val <= "0001";
        xx_1_val <= "0110";
      END IF;
    WHEN 110  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 177 
        xx_0_val <= "0110";
        xx_1_val <= "0010";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 178 
        xx_0_val <= "0010";
        xx_1_val <= "0110";
      END IF;
    WHEN 111  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 179 
        xx_0_val <= "0101";
        xx_1_val <= "0100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 180 
        xx_0_val <= "0100";
        xx_1_val <= "0101";
      END IF;
    WHEN 112  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 181 
        xx_0_val <= "0110";
        xx_1_val <= "0011";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 182 
        xx_0_val <= "0011";
        xx_1_val <= "0110";
      END IF;
    WHEN 113  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 183 
        xx_0_val <= "0111";
        xx_1_val <= "0001";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 184 
        xx_0_val <= "0101";
        xx_1_val <= "0101";
      END IF;
    WHEN 114  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 185 
        xx_0_val <= "0110";
        xx_1_val <= "0100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 186 
        xx_0_val <= "0100";
        xx_1_val <= "0110";
      END IF;
    WHEN 115  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 187 
        xx_0_val <= "0111";
        xx_1_val <= "0010";
      ELSE
        ns <= 188 ;--BAABAAAB -- 188
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 116  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 189 
        xx_0_val <= "0111";
        xx_1_val <= "0011";
      ELSE
        ns <= 190 ;--BAABAABB -- 190
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 117  =>
      IF(inp = '1') THEN
        ns <= 191 ;--BAABABAA -- 191
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 192 ;--BAABABAB -- 192
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 118  =>
      IF(inp = '1') THEN
        ns <= 193 ;--BAABABBA -- 193
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 194 ;--BAABABBB -- 194
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 119  =>
      IF(inp = '1') THEN
        ns <= 195 ;--BAABBAAA -- 195
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 196 ;--BAABBAAB -- 196
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 120  =>
      IF(inp = '1') THEN
        ns <= 197 ;--BAABBABA -- 197
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 198 ;--BAABBABB -- 198
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 121  =>
      IF(inp = '1') THEN
        ns <= 199 ;--BAABBBAA -- 199
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 200 ;--BAABBBAB -- 200
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 122  =>
      IF(inp = '1') THEN
        ns <= 201 ;--BAABBBBA -- 201
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 202 ;--BAABBBBB -- 202
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 123  =>
      IF(inp = '1') THEN
        ns <= 203 ;--BABAAAAA -- 203
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 204 ;--BABAAAAB -- 204
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 124  =>
      IF(inp = '1') THEN
        ns <= 205 ;--BABAAABA -- 205
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 206 ;--BABAAABB -- 206
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 125  =>
      IF(inp = '1') THEN
        ns <= 207 ;--BABAABAA -- 207
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 208 ;--BABAABAB -- 208
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 126  =>
      IF(inp = '1') THEN
        ns <= 209 ;--BABAABBA -- 209
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 210 ;--BABAABBB -- 210
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 127  =>
      IF(inp = '1') THEN
        ns <= 211 ;--BABABAAA -- 211
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 212 ;--BABABAAB -- 212
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 128  =>
      IF(inp = '1') THEN
        ns <= 213 ;--BABABABA -- 213
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 214 ;--BABABABB -- 214
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 129  =>
      IF(inp = '1') THEN
        ns <= 215 ;--BABABBAA -- 215
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 216 ;--BABABBAB -- 216
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 130  =>
      IF(inp = '1') THEN
        ns <= 217 ;--BABABBBA -- 217
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 218 ;--BABABBBB -- 218
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 131  =>
      IF(inp = '1') THEN
        ns <= 219 ;--BABBAAAA -- 219
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 220 ;--BABBAAAB -- 220
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 132  =>
      IF(inp = '1') THEN
        ns <= 221 ;--BABBAABA -- 221
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 222 ;--BABBAABB -- 222
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 133  =>
      IF(inp = '1') THEN
        ns <= 223 ;--BABBABAA -- 223
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 224 ;--BABBABAB -- 224
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 134  =>
      IF(inp = '1') THEN
        ns <= 225 ;--BABBABBA -- 225
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 226 ;--BABBABBB -- 226
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 135  =>
      IF(inp = '1') THEN
        ns <= 227 ;--BABBBAAA -- 227
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 228 ;--BABBBAAB -- 228
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 136  =>
      IF(inp = '1') THEN
        ns <= 229 ;--BABBBABA -- 229
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 230 ;--BABBBABB -- 230
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 137  =>
      IF(inp = '1') THEN
        ns <= 231 ;--BABBBBAA -- 231
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 232 ;--BABBBBAB -- 232
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 138  =>
      IF(inp = '1') THEN
        ns <= 233 ;--BABBBBBA -- 233
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 234 ;--BABBBBBB -- 234
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 139  =>
      IF(inp = '1') THEN
        ns <= 235 ;--BBABAAAA -- 235
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 236 ;--BBABAAAB -- 236
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 140  =>
      IF(inp = '1') THEN
        ns <= 237 ;--BBABAABA -- 237
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 238 ;--BBABAABB -- 238
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 141  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 239 
        xx_0_val <= "1111";
        xx_1_val <= "0000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 240 
        xx_0_val <= "0001";
        xx_1_val <= "1111";
      END IF;
    WHEN 154  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 241 
        xx_0_val <= "0111";
        xx_1_val <= "1111";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 242 
        xx_0_val <= "1000";
        xx_1_val <= "1111";
      END IF;
    WHEN 157  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 243 
        xx_0_val <= "1001";
        xx_1_val <= "1111";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 244 
        xx_0_val <= "1010";
        xx_1_val <= "1111";
      END IF;
    WHEN 159  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 245 
        xx_0_val <= "1111";
        xx_1_val <= "1011";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 246 
        xx_0_val <= "1011";
        xx_1_val <= "1111";
      END IF;
    WHEN 160  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 247 
        xx_0_val <= "1111";
        xx_1_val <= "1100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 248 
        xx_0_val <= "1100";
        xx_1_val <= "1111";
      END IF;
    WHEN 161  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 249 
        xx_0_val <= "1111";
        xx_1_val <= "1101";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 250 
        xx_0_val <= "1101";
        xx_1_val <= "1111";
      END IF;
    WHEN 162  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 251 
        xx_0_val <= "1111";
        xx_1_val <= "1110";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 252 
        xx_0_val <= "1110";
        xx_1_val <= "1111";
      END IF;
    WHEN 167  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 253 
        xx_0_val <= "0101";
        xx_1_val <= "0000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 254 
        xx_0_val <= "0000";
        xx_1_val <= "0101";
      END IF;
    WHEN 174  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 255 
        xx_0_val <= "0110";
        xx_1_val <= "0000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 256 
        xx_0_val <= "0000";
        xx_1_val <= "0110";
      END IF;
    WHEN 188  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 257 
        xx_0_val <= "0010";
        xx_1_val <= "0111";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 258 
        xx_0_val <= "0011";
        xx_1_val <= "0111";
      END IF;
    WHEN 190  =>
      IF(inp = '1') THEN
        ns <= 259 ;--BAABAABBA -- 259
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 260 
        xx_0_val <= "0001";
        xx_1_val <= "0111";
      END IF;
    WHEN 191  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 261 
        xx_0_val <= "0110";
        xx_1_val <= "0101";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 262 
        xx_0_val <= "0101";
        xx_1_val <= "0110";
      END IF;
    WHEN 192  =>
      IF(inp = '1') THEN
        ns <= 263 ;--BAABABABA -- 263
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 264 
        xx_0_val <= "1000";
        xx_1_val <= "0001";
      END IF;
    WHEN 193  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 265 
        xx_0_val <= "0111";
        xx_1_val <= "0100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 266 
        xx_0_val <= "0100";
        xx_1_val <= "0111";
      END IF;
    WHEN 194  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 267 
        xx_0_val <= "0001";
        xx_1_val <= "1000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 268 
        xx_0_val <= "1000";
        xx_1_val <= "0010";
      END IF;
    WHEN 195  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 269 
        xx_0_val <= "0010";
        xx_1_val <= "1000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 270 
        xx_0_val <= "0110";
        xx_1_val <= "0110";
      END IF;
    WHEN 196  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 271 
        xx_0_val <= "1000";
        xx_1_val <= "0011";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 272 
        xx_0_val <= "0011";
        xx_1_val <= "1000";
      END IF;
    WHEN 197  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 273 
        xx_0_val <= "0111";
        xx_1_val <= "0101";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 274 
        xx_0_val <= "0101";
        xx_1_val <= "0111";
      END IF;
    WHEN 198  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 275 
        xx_0_val <= "1000";
        xx_1_val <= "0100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 276 
        xx_0_val <= "0100";
        xx_1_val <= "1000";
      END IF;
    WHEN 199  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 277 
        xx_0_val <= "1001";
        xx_1_val <= "0001";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 278 
        xx_0_val <= "0001";
        xx_1_val <= "1001";
      END IF;
    WHEN 200  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 279 
        xx_0_val <= "1001";
        xx_1_val <= "0010";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 280 
        xx_0_val <= "0111";
        xx_1_val <= "0110";
      END IF;
    WHEN 201  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 281 
        xx_0_val <= "0110";
        xx_1_val <= "0111";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 282 
        xx_0_val <= "0010";
        xx_1_val <= "1001";
      END IF;
    WHEN 202  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 283 
        xx_0_val <= "1000";
        xx_1_val <= "0101";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 284 
        xx_0_val <= "0101";
        xx_1_val <= "1000";
      END IF;
    WHEN 203  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 285 
        xx_0_val <= "1001";
        xx_1_val <= "0011";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 286 
        xx_0_val <= "0011";
        xx_1_val <= "1001";
      END IF;
    WHEN 204  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 287 
        xx_0_val <= "1001";
        xx_1_val <= "0100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 288 
        xx_0_val <= "0100";
        xx_1_val <= "1001";
      END IF;
    WHEN 205  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 289 
        xx_0_val <= "0111";
        xx_1_val <= "0111";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 290 
        xx_0_val <= "1000";
        xx_1_val <= "0110";
      END IF;
    WHEN 206  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 291 
        xx_0_val <= "0110";
        xx_1_val <= "1000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 292 
        xx_0_val <= "1010";
        xx_1_val <= "0001";
      END IF;
    WHEN 207  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 293 
        xx_0_val <= "1010";
        xx_1_val <= "0010";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 294 
        xx_0_val <= "0010";
        xx_1_val <= "1010";
      END IF;
    WHEN 208  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 295 
        xx_0_val <= "1001";
        xx_1_val <= "0101";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 296 
        xx_0_val <= "0101";
        xx_1_val <= "1001";
      END IF;
    WHEN 209  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 297 
        xx_0_val <= "1010";
        xx_1_val <= "0011";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 298 
        xx_0_val <= "0011";
        xx_1_val <= "1010";
      END IF;
    WHEN 210  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 299 
        xx_0_val <= "1000";
        xx_1_val <= "0111";
      ELSE
        ns <= 300 ;--BABAABBBB -- 300
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 211  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 301 
        xx_0_val <= "1010";
        xx_1_val <= "0100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 302 
        xx_0_val <= "1001";
        xx_1_val <= "0110";
      END IF;
    WHEN 212  =>
      IF(inp = '1') THEN
        ns <= 303 ;--BABABAABA -- 303
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 304 ;--BABABAABB -- 304
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 213  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 305 
        xx_0_val <= "1011";
        xx_1_val <= "0010";
      ELSE
        ns <= 306 ;--BABABABAB -- 306
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 214  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 307 
        xx_0_val <= "1000";
        xx_1_val <= "1000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 308 
        xx_0_val <= "1011";
        xx_1_val <= "0011";
      END IF;
    WHEN 215  =>
      IF(inp = '1') THEN
        ns <= 309 ;--BABABBAAA -- 309
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 310 ;--BABABBAAB -- 310
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 216  =>
      IF(inp = '1') THEN
        ns <= 311 ;--BABABBABA -- 311
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 312 
        xx_0_val <= "1011";
        xx_1_val <= "0100";
      END IF;
    WHEN 217  =>
      IF(inp = '1') THEN
        ns <= 313 ;--BABABBBAA -- 313
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 314 ;--BABABBBAB -- 314
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 218  =>
      IF(inp = '1') THEN
        ns <= 315 ;--BABABBBBA -- 315
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 316 ;--BABABBBBB -- 316
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 219  =>
      IF(inp = '1') THEN
        ns <= 317 ;--BABBAAAAA -- 317
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 318 ;--BABBAAAAB -- 318
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 220  =>
      IF(inp = '1') THEN
        ns <= 319 ;--BABBAAABA -- 319
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 320 ;--BABBAAABB -- 320
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 221  =>
      IF(inp = '1') THEN
        ns <= 321 ;--BABBAABAA -- 321
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 322 ;--BABBAABAB -- 322
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 222  =>
      IF(inp = '1') THEN
        ns <= 323 ;--BABBAABBA -- 323
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 324 ;--BABBAABBB -- 324
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 223  =>
      IF(inp = '1') THEN
        ns <= 325 ;--BABBABAAA -- 325
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 326 ;--BABBABAAB -- 326
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 224  =>
      IF(inp = '1') THEN
        ns <= 327 ;--BABBABABA -- 327
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 328 ;--BABBABABB -- 328
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 225  =>
      IF(inp = '1') THEN
        ns <= 329 ;--BABBABBAA -- 329
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 330 ;--BABBABBAB -- 330
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 226  =>
      IF(inp = '1') THEN
        ns <= 331 ;--BABBABBBA -- 331
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 332 ;--BABBABBBB -- 332
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 227  =>
      IF(inp = '1') THEN
        ns <= 333 ;--BABBBAAAA -- 333
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 334 ;--BABBBAAAB -- 334
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 228  =>
      IF(inp = '1') THEN
        ns <= 335 ;--BABBBAABA -- 335
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 336 ;--BABBBAABB -- 336
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 229  =>
      IF(inp = '1') THEN
        ns <= 337 ;--BABBBABAA -- 337
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 338 ;--BABBBABAB -- 338
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 230  =>
      IF(inp = '1') THEN
        ns <= 339 ;--BABBBABBA -- 339
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 340 ;--BABBBABBB -- 340
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 231  =>
      IF(inp = '1') THEN
        ns <= 341 ;--BABBBBAAA -- 341
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 342 ;--BABBBBAAB -- 342
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 232  =>
      IF(inp = '1') THEN
        ns <= 343 ;--BABBBBABA -- 343
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 344 ;--BABBBBABB -- 344
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 233  =>
      IF(inp = '1') THEN
        ns <= 345 ;--BABBBBBAA -- 345
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 346 ;--BABBBBBAB -- 346
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 234  =>
      IF(inp = '1') THEN
        ns <= 347 ;--BABBBBBBA -- 347
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 348 ;--BABBBBBBB -- 348
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 235  =>
      IF(inp = '1') THEN
        ns <= 349 ;--BBABAAAAA -- 349
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 350 ;--BBABAAAAB -- 350
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 236  =>
      IF(inp = '1') THEN
        ns <= 351 ;--BBABAAABA -- 351
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 352 ;--BBABAAABB -- 352
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 237  =>
      IF(inp = '1') THEN
        ns <= 353 ;--BBABAABAA -- 353
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 354 ;--BBABAABAB -- 354
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 238  =>
      IF(inp = '1') THEN
        ns <= 355 ;--BBABAABBA -- 355
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 356 
        xx_0_val <= "0000";
        xx_1_val <= "1111";
      END IF;
    WHEN 259  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 357 
        xx_0_val <= "0111";
        xx_1_val <= "0000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 358 
        xx_0_val <= "0000";
        xx_1_val <= "0111";
      END IF;
    WHEN 263  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 359 
        xx_0_val <= "1000";
        xx_1_val <= "0000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 360 
        xx_0_val <= "0000";
        xx_1_val <= "1000";
      END IF;
    WHEN 300  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 361 
        xx_0_val <= "0111";
        xx_1_val <= "1000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 362 
        xx_0_val <= "0100";
        xx_1_val <= "1010";
      END IF;
    WHEN 303  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 363 
        xx_0_val <= "0110";
        xx_1_val <= "1001";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 364 
        xx_0_val <= "1011";
        xx_1_val <= "0001";
      END IF;
    WHEN 304  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 365 
        xx_0_val <= "0001";
        xx_1_val <= "1011";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 366 
        xx_0_val <= "1010";
        xx_1_val <= "0101";
      END IF;
    WHEN 306  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 367 
        xx_0_val <= "0101";
        xx_1_val <= "1010";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 368 
        xx_0_val <= "0010";
        xx_1_val <= "1011";
      END IF;
    WHEN 309  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 369 
        xx_0_val <= "1001";
        xx_1_val <= "0000";
      ELSE
        ns <= 370 ;--BABABBAAAB -- 370
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 310  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 371 
        xx_0_val <= "1001";
        xx_1_val <= "0111";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 372 
        xx_0_val <= "0111";
        xx_1_val <= "1001";
      END IF;
    WHEN 311  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 373 
        xx_0_val <= "1010";
        xx_1_val <= "0110";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 374 
        xx_0_val <= "0110";
        xx_1_val <= "1010";
      END IF;
    WHEN 313  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 375 
        xx_0_val <= "0001";
        xx_1_val <= "1010";
      ELSE
        ns <= 376 ;--BABABBBAAB -- 376
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 314  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 377 
        xx_0_val <= "0011";
        xx_1_val <= "1011";
      ELSE
        ns <= 378 ;--BABABBBABB -- 378
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 315  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 379 
        xx_0_val <= "0100";
        xx_1_val <= "1011";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 380 
        xx_0_val <= "1100";
        xx_1_val <= "0001";
      END IF;
    WHEN 316  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 381 
        xx_0_val <= "1001";
        xx_1_val <= "1000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 382 
        xx_0_val <= "1000";
        xx_1_val <= "1001";
      END IF;
    WHEN 317  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 383 
        xx_0_val <= "0001";
        xx_1_val <= "1100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 384 
        xx_0_val <= "1011";
        xx_1_val <= "0101";
      END IF;
    WHEN 318  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 385 
        xx_0_val <= "0101";
        xx_1_val <= "1011";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 386 
        xx_0_val <= "1100";
        xx_1_val <= "0010";
      END IF;
    WHEN 319  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 387 
        xx_0_val <= "0010";
        xx_1_val <= "1100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 388 
        xx_0_val <= "1010";
        xx_1_val <= "0111";
      END IF;
    WHEN 320  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 389 
        xx_0_val <= "0111";
        xx_1_val <= "1010";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 390 
        xx_0_val <= "1100";
        xx_1_val <= "0011";
      END IF;
    WHEN 321  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 391 
        xx_0_val <= "0011";
        xx_1_val <= "1100";
      ELSE
        ns <= 392 ;--BABBAABAAB -- 392
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 322  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 393 
        xx_0_val <= "1011";
        xx_1_val <= "0110";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 394 
        xx_0_val <= "0110";
        xx_1_val <= "1011";
      END IF;
    WHEN 323  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 395 
        xx_0_val <= "1100";
        xx_1_val <= "0100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 396 
        xx_0_val <= "0100";
        xx_1_val <= "1100";
      END IF;
    WHEN 324  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 397 
        xx_0_val <= "1001";
        xx_1_val <= "1001";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 398 
        xx_0_val <= "1010";
        xx_1_val <= "1000";
      END IF;
    WHEN 325  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 399 
        xx_0_val <= "1000";
        xx_1_val <= "1010";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 400 
        xx_0_val <= "1100";
        xx_1_val <= "0101";
      END IF;
    WHEN 326  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 401 
        xx_0_val <= "0101";
        xx_1_val <= "1100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 402 
        xx_0_val <= "1101";
        xx_1_val <= "0001";
      END IF;
    WHEN 327  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 403 
        xx_0_val <= "1011";
        xx_1_val <= "0111";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 404 
        xx_0_val <= "0111";
        xx_1_val <= "1011";
      END IF;
    WHEN 328  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 405 
        xx_0_val <= "0001";
        xx_1_val <= "1101";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 406 
        xx_0_val <= "1101";
        xx_1_val <= "0010";
      END IF;
    WHEN 329  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 407 
        xx_0_val <= "0010";
        xx_1_val <= "1101";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 408 
        xx_0_val <= "1101";
        xx_1_val <= "0011";
      END IF;
    WHEN 330  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 409 
        xx_0_val <= "0011";
        xx_1_val <= "1101";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 410 
        xx_0_val <= "1100";
        xx_1_val <= "0110";
      END IF;
    WHEN 331  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 411 
        xx_0_val <= "0110";
        xx_1_val <= "1100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 412 
        xx_0_val <= "1010";
        xx_1_val <= "1001";
      END IF;
    WHEN 332  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 413 
        xx_0_val <= "1001";
        xx_1_val <= "1010";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 414 
        xx_0_val <= "1101";
        xx_1_val <= "0100";
      END IF;
    WHEN 333  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 415 
        xx_0_val <= "1011";
        xx_1_val <= "1000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 416 
        xx_0_val <= "1000";
        xx_1_val <= "1011";
      END IF;
    WHEN 334  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 417 
        xx_0_val <= "0100";
        xx_1_val <= "1101";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 418 
        xx_0_val <= "1100";
        xx_1_val <= "0111";
      END IF;
    WHEN 335  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 419 
        xx_0_val <= "0111";
        xx_1_val <= "1100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 420 
        xx_0_val <= "1101";
        xx_1_val <= "0101";
      END IF;
    WHEN 336  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 421 
        xx_0_val <= "0101";
        xx_1_val <= "1101";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 422 
        xx_0_val <= "1110";
        xx_1_val <= "0001";
      END IF;
    WHEN 337  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 423 
        xx_0_val <= "0001";
        xx_1_val <= "1110";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 424 
        xx_0_val <= "1110";
        xx_1_val <= "0010";
      END IF;
    WHEN 338  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 425 
        xx_0_val <= "1010";
        xx_1_val <= "1010";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 426 
        xx_0_val <= "1011";
        xx_1_val <= "1001";
      END IF;
    WHEN 339  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 427 
        xx_0_val <= "1001";
        xx_1_val <= "1011";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 428 
        xx_0_val <= "1110";
        xx_1_val <= "0011";
      END IF;
    WHEN 340  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 429 
        xx_0_val <= "1101";
        xx_1_val <= "0110";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 430 
        xx_0_val <= "0110";
        xx_1_val <= "1101";
      END IF;
    WHEN 341  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 431 
        xx_0_val <= "0011";
        xx_1_val <= "1110";
      ELSE
        ns <= 432 ;--BABBBBAAAB -- 432
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 342  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 433 
        xx_0_val <= "1100";
        xx_1_val <= "1000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 434 
        xx_0_val <= "1000";
        xx_1_val <= "1100";
      END IF;
    WHEN 343  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 435 
        xx_0_val <= "1110";
        xx_1_val <= "0100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 436 
        xx_0_val <= "1101";
        xx_1_val <= "0111";
      END IF;
    WHEN 344  =>
      IF(inp = '1') THEN
        ns <= 437 ;--BABBBBABBA -- 437
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 438 
        xx_0_val <= "1110";
        xx_1_val <= "0101";
      END IF;
    WHEN 345  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 439 
        xx_0_val <= "1011";
        xx_1_val <= "1010";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 440 
        xx_0_val <= "0101";
        xx_1_val <= "1110";
      END IF;
    WHEN 346  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 441 
        xx_0_val <= "1100";
        xx_1_val <= "1001";
      ELSE
        ns <= 442 ;--BABBBBBABB -- 442
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 347  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 443 
        xx_0_val <= "1110";
        xx_1_val <= "0110";
      ELSE
        ns <= 444 ;--BABBBBBBAB -- 444
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 348  =>
      IF(inp = '1') THEN
        ns <= 445 ;--BABBBBBBBA -- 445
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 446 ;--BABBBBBBBB -- 446
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 349  =>
      IF(inp = '1') THEN
        ns <= 447 ;--BBABAAAAAA -- 447
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 448 ;--BBABAAAAAB -- 448
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 350  =>
      IF(inp = '1') THEN
        ns <= 449 ;--BBABAAAABA -- 449
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 450 ;--BBABAAAABB -- 450
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 351  =>
      IF(inp = '1') THEN
        ns <= 451 ;--BBABAAABAA -- 451
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 452 ;--BBABAAABAB -- 452
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 352  =>
      IF(inp = '1') THEN
        ns <= 453 ;--BBABAAABBA -- 453
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 454 ;--BBABAAABBB -- 454
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 353  =>
      IF(inp = '1') THEN
        ns <= 455 ;--BBABAABAAA -- 455
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 456 ;--BBABAABAAB -- 456
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 354  =>
      IF(inp = '1') THEN
        ns <= 457 ;--BBABAABABA -- 457
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 458 ;--BBABAABABB -- 458
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 355  =>
      IF(inp = '1') THEN
        ns <= 459 ;--BBABAABBAA -- 459
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      ELSE
        ns <= 460 ;--BBABAABBAB -- 460
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 370  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 461 
        xx_0_val <= "0000";
        xx_1_val <= "1001";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 462 
        xx_0_val <= "1010";
        xx_1_val <= "0000";
      END IF;
    WHEN 376  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 463 
        xx_0_val <= "0000";
        xx_1_val <= "1010";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 464 
        xx_0_val <= "1011";
        xx_1_val <= "0000";
      END IF;
    WHEN 378  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 465 
        xx_0_val <= "0000";
        xx_1_val <= "1011";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 466 
        xx_0_val <= "1100";
        xx_1_val <= "0000";
      END IF;
    WHEN 392  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 467 
        xx_0_val <= "0000";
        xx_1_val <= "1100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 468 
        xx_0_val <= "1101";
        xx_1_val <= "0000";
      END IF;
    WHEN 432  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 469 
        xx_0_val <= "0010";
        xx_1_val <= "1110";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 470 
        xx_0_val <= "0100";
        xx_1_val <= "1110";
      END IF;
    WHEN 437  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 471 
        xx_0_val <= "0111";
        xx_1_val <= "1101";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 472 
        xx_0_val <= "1010";
        xx_1_val <= "1011";
      END IF;
    WHEN 442  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 473 
        xx_0_val <= "1001";
        xx_1_val <= "1100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 474 
        xx_0_val <= "0110";
        xx_1_val <= "1110";
      END IF;
    WHEN 444  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 475 
        xx_0_val <= "0000";
        xx_1_val <= "1101";
      ELSE
        ns <= 476 ;--BABBBBBBABB -- 476
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
      END IF;
    WHEN 445  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 477 
        xx_0_val <= "1101";
        xx_1_val <= "1000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 478 
        xx_0_val <= "1000";
        xx_1_val <= "1101";
      END IF;
    WHEN 446  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 479 
        xx_0_val <= "1011";
        xx_1_val <= "1011";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 480 
        xx_0_val <= "1100";
        xx_1_val <= "1010";
      END IF;
    WHEN 447  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 481 
        xx_0_val <= "1010";
        xx_1_val <= "1100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 482 
        xx_0_val <= "1110";
        xx_1_val <= "0111";
      END IF;
    WHEN 448  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 483 
        xx_0_val <= "0111";
        xx_1_val <= "1110";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 484 
        xx_0_val <= "1101";
        xx_1_val <= "1001";
      END IF;
    WHEN 449  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 485 
        xx_0_val <= "1001";
        xx_1_val <= "1101";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 486 
        xx_0_val <= "1110";
        xx_1_val <= "1000";
      END IF;
    WHEN 450  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 487 
        xx_0_val <= "1000";
        xx_1_val <= "1110";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 488 
        xx_0_val <= "1100";
        xx_1_val <= "1011";
      END IF;
    WHEN 451  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 489 
        xx_0_val <= "1011";
        xx_1_val <= "1100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 490 
        xx_0_val <= "1101";
        xx_1_val <= "1010";
      END IF;
    WHEN 452  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 491 
        xx_0_val <= "1010";
        xx_1_val <= "1101";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 492 
        xx_0_val <= "1110";
        xx_1_val <= "1001";
      END IF;
    WHEN 453  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 493 
        xx_0_val <= "1001";
        xx_1_val <= "1110";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 494 
        xx_0_val <= "1100";
        xx_1_val <= "1100";
      END IF;
    WHEN 454  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 495 
        xx_0_val <= "1101";
        xx_1_val <= "1011";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 496 
        xx_0_val <= "1011";
        xx_1_val <= "1101";
      END IF;
    WHEN 455  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 497 
        xx_0_val <= "1110";
        xx_1_val <= "1010";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 498 
        xx_0_val <= "1010";
        xx_1_val <= "1110";
      END IF;
    WHEN 456  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 499 
        xx_0_val <= "1101";
        xx_1_val <= "1100";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 500 
        xx_0_val <= "1100";
        xx_1_val <= "1101";
      END IF;
    WHEN 457  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 501 
        xx_0_val <= "1110";
        xx_1_val <= "1011";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 502 
        xx_0_val <= "1011";
        xx_1_val <= "1110";
      END IF;
    WHEN 458  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 503 
        xx_0_val <= "1101";
        xx_1_val <= "1101";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 504 
        xx_0_val <= "1110";
        xx_1_val <= "1100";
      END IF;
    WHEN 459  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 505 
        xx_0_val <= "1100";
        xx_1_val <= "1110";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 506 
        xx_0_val <= "1110";
        xx_1_val <= "1101";
      END IF;
    WHEN 460  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 507 
        xx_0_val <= "1101";
        xx_1_val <= "1110";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 508 
        xx_0_val <= "1110";
        xx_1_val <= "1110";
      END IF;
    WHEN 476  =>
      IF(inp = '1') THEN
        ns <= 0 ;
        found_sig <= '1'; -- 509 
        xx_0_val <= "1110";
        xx_1_val <= "0000";
      ELSE
        ns <= 0 ;
        found_sig <= '1'; -- 510 
        xx_0_val <= "0000";
        xx_1_val <= "1110";
      END IF;
    WHEN OTHERS  => 
        ns <= 0 ; 
        found_sig <= '0';
        xx_0_val <= (others => 'X');
        xx_1_val <= (others => 'X');
  END CASE; 
END PROCESS st_mac;

decode: PROCESS(clk_in,clr_n)
BEGIN
  IF(clr_n = '0') THEN
    ps <= 0;
    found_sync <= '0';
  ELSIF(rising_edge(clk_in)) THEN
    IF(start = '1') THEN
      ps <= ns;
      found_sync <= found_sig;
    ELSE
      ps <= ps;
      found_sync <= found_sync;
    END IF;
  END IF;
END PROCESS decode;
  

enc_val: PROCESS(clk_in,clr_n)
BEGIN
  IF(clr_n = '0') THEN
--
    xx_0_val_sync <= (others => '0');
    xx_1_val_sync <= (others => '0');
--#b#
  ELSIF(rising_edge(clk_in)) THEN
    IF(found_sig = '1') THEN
--
      xx_0_val_sync <= xx_0_val;
      xx_1_val_sync <= xx_1_val;
--#b#
    END IF;
  END IF;
END PROCESS enc_val;

--
xx_0_value <= xx_0_val_sync;
xx_1_value <= xx_1_val_sync;
--#b#
--##############################################################################
--  Process: 
--##############################################################################



END rtl;
--##############################################################################
--Architecture Ends
--##############################################################################

--##############################################################################
--Notes Begins
--##############################################################################

--##############################################################################
--Notes Ends
--##############################################################################



